==> haskell-irc-core-2.11-49-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 irc-core
version:              2.11
visibility:           public
id:                   irc-core-2.11-DYfkSFqVXidJFeGlXGUdGL
key:                  irc-core-2.11-DYfkSFqVXidJFeGlXGUdGL
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc

    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  77dbdfecf7d6360b88e0ffb0c1db04fe
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.2.8/site-local/irc-core-2.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/irc-core-2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.11-DYfkSFqVXidJFeGlXGUdGL
depends:
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    bytestring-0.11.4.0 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF text-1.2.5.0 time-1.11.1.1
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-irc-core-2.11-51-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 irc-core
version:              2.11
visibility:           public
id:                   irc-core-2.11-Eyj7VA0MZ3j6B4HhF0zM5s
key:                  irc-core-2.11-Eyj7VA0MZ3j6B4HhF0zM5s
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc

    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  d5a5dbe4e2f489ae7332bcfb00f263db
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.2.8/site-local/irc-core-2.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/irc-core-2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.11-Eyj7VA0MZ3j6B4HhF0zM5s
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj bytestring-0.11.4.0
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx text-1.2.5.0 time-1.11.1.1
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
